@@ -15,104 +15,6 @@ import xml.etree.ElementTree as ET
 
 
 # Monkey patch the jenkins import
-def _response_handler(self, response):  # pragma: no cover
-    '''Handle response objects'''
-    # raise exceptions if occurred
-    response.raise_for_status()
-    headers = response.headers
-    if (headers.get('content-length') is None and
-            headers.get('transfer-encoding') is None and
-            len(response.content) <= 0):
-        # response body should only exist if one of these is provided
-        raise jenkins.EmptyResponseException(
-            "Error communicating with server[%s]: "
-            "empty response" % self.server)
-    # Response objects will automatically return unicode encoded
-    # when accessing .text property
-    return response
-
-
-jenkins.Jenkins._response_handler = _response_handler
-
-
-BUILD_ENV_VARS = '%(folder_url)sjob/%(short_name)s/%(number)d/injectedEnvVars/api/json' + \
-    '?depth=%(depth)s'
-
-
-def get_build_env_vars(self, name, number, depth=0):
-    '''Get build environment variables.
-
-    :param name: Job name, ``str``
-    :param name: Build number, ``int``
-    :param depth: JSON depth, ``int``
-    :returns: dictionary of build env vars, ``dict``
-    '''
-    folder_url, short_name = self._get_job_folder(name)
-    try:
-        response = self.jenkins_open(requests.Request(
-                'GET', self._build_url(BUILD_ENV_VARS, locals())
-            ))
-        if response:
-            return json.loads(response)
-        else:
-            raise jenkins.JenkinsException('job[%s] number[%d] does not exist'
-                                           % (name, number))
-    except requests.exceptions.HTTPError:
-        raise jenkins.JenkinsException('job[%s] number[%d] does not exist'
-                                       % (name, number))
-    except ValueError:
-        raise jenkins.JenkinsException(
-            'Could not parse JSON info for job[%s] number[%d]'
-            % (name, number)
-        )
-    except jenkins.NotFoundException as e:
-        # This can happen on workflow jobs, or if InjectEnvVars plugin not installed
-        print("Not retrieving env_vars: %s" % e)
-        return None
-
-
-jenkins.Jenkins.get_build_env_vars = get_build_env_vars
-
-
-# Get Test results
-BUILD_TEST_REPORT = '%(folder_url)sjob/%(short_name)s/%(number)d/testReport/api/json' + \
-    '?depth=%(depth)s'
-
-
-def get_build_test_report(self, name, number, depth=0):
-    '''Get test results report.
-
-    :param name: Job name, ``str``
-    :param name: Build number, ``int``
-    :returns: dictionary of test report results, ``dict``
-    '''
-    folder_url, short_name = self._get_job_folder(name)
-    try:
-        response = self.jenkins_open(requests.Request(
-                'GET', self._build_url(BUILD_TEST_REPORT, locals())
-            ))
-        if response:
-            return json.loads(response)
-        else:
-            raise jenkins.JenkinsException('job[%s] number[%d] does not exist'
-                                           % (name, number))
-    except requests.exceptions.HTTPError:
-        raise jenkins.JenkinsException('job[%s] number[%d] does not exist'
-                                       % (name, number))
-    except ValueError:
-        raise jenkins.JenkinsException(
-            'Could not parse JSON info for job[%s] number[%d]'
-            % (name, number)
-        )
-    except jenkins.NotFoundException as e:
-        # This can happen if the test report wasn't generated for any reason
-        print("Not retrieving test report: %s" % e)
-        return None
-
-
-jenkins.Jenkins.get_build_test_report = get_build_test_report
-
-
 # Get Artifact
 BUILD_ARTIFACT = '%(folder_url)sjob/%(short_name)s/%(number)d/artifact/%(artifact)s'
 
@@ -334,6 +236,7 @@ class EsLogger(object):
         # Add the base info we have
         self.es_info[self.data_name]['job_name'] = self.es_job_name
         self.es_info[self.data_name]['jenkins_url'] = self.jenkins_url
+        self.es_info[self.data_name]['build_number'] = self.es_build_number
 
         # Build Info (Parameters, Status)
         self.build_info = self.server.get_build_info(self.es_job_name, self.es_build_number,
@@ -467,10 +370,13 @@ class EsLogger(object):
         # Max length for an indexed field is 32766, if longer, reduce
         # Default value in args parsing is 32500,
         # as when using larger values saw failures (not sure why)
-        if len(self.console_log) > self.console_length:
+        console_log_length = len(self.console_log)
+        if console_log_length > self.console_length:
             self.es_info['console_log'] = self.console_log[-self.console_length:]
         else:
             self.es_info['console_log'] = self.console_log
+        # Add the length of the console log
+        self.es_info['console_log_length'] = console_log_length
 
     def get_event_info(self, fields):
         event_info = {'build_info': {}}
