@@ -35,13 +35,10 @@ class TestEsLogger(object):
 
         self.esl = es_logger.EsLogger(1000, ['dummy'])
         self.urls = {
-            'get_build_env_vars': 'jenkins_url/job/job_name/1/injectedEnvVars/api/json?depth=1',
-            'get_build_test_report': 'jenkins_url/job/job_name/1/testReport/api/json?depth=1',
             'get_build_artifact': 'jenkins_url/job/job_name/1/artifact/1',
             'get_build_stages': 'jenkins_url/job/job_name/1/wfapi/describe/'}
 
-    @parameterized.expand(['get_build_env_vars', 'get_build_test_report', 'get_build_artifact',
-                           'get_build_stages'])
+    @parameterized.expand(['get_build_artifact', 'get_build_stages'])
     def test_monkey_patch(self, param):
         with unittest.mock.patch('es_logger.jenkins.Jenkins.jenkins_open') as mock_open:
             self.esl.server.crumb = False
@@ -222,6 +219,18 @@ class TestEsLogger(object):
             # Console log recorded
             nose.tools.ok_(self.esl.es_info['console_log'] == 'log',
                            "console_log not 'log': {}".format(self.esl.es_info))
+            # Console log length recorded
+            nose.tools.ok_(self.esl.es_info['console_log_length'] == 3,
+                           "console_log length not 3: {}".format(self.esl.es_info))
+
+            # ID info pulled into eslogger namespace
+            eslogger_vars = {'job_name': 'es_job_name',
+                             'jenkins_url': 'jenkins_url',
+                             'build_number': '2'}
+            for k, v in eslogger_vars.items():
+                nose.tools.ok_(self.esl.es_info['eslogger'][k] == v,
+                               "{} not {}: {}".format(k, v, self.esl.es_info))
+
             # Parameters pulled out
             nose.tools.ok_(self.esl.es_info['parameters'].get('param') == 'value',
                            "Parameter 'param' not 'value': {}".format(self.esl.es_info))
